@@ -36,13 +36,10 @@
 #include <stdarg.h>
 
 #include <gst/gst.h>
+#include <gst/pbutils/pbutils.h>
 
 #include "banshee-gst.h"
 
-#ifdef HAVE_GST_PBUTILS
-#  include <gst/pbutils/pbutils.h>
-#endif
-
 static gboolean gstreamer_initialized = FALSE;
 static gboolean banshee_debugging;
 static BansheeLogHandler banshee_log_handler = NULL;
@@ -60,9 +57,7 @@ gstreamer_initialize (gboolean debugging, BansheeLogHandler log_handler)
 
     gst_init (NULL, NULL);
     
-    #ifdef HAVE_GST_PBUTILS
     gst_pb_utils_init ();
-    #endif
     
     gstreamer_initialized = TRUE;
 }
@@ -82,6 +77,12 @@ gstreamer_test_pipeline (gchar *pipeline)
     return error == NULL;
 }
 
+MYEXPORT gchar *
+gstreamer_version_string ()
+{
+    return g_strdup_printf ("%i.%i.%i.%i", GST_VERSION_MAJOR, GST_VERSION_MINOR, GST_VERSION_MICRO, GST_VERSION_NANO);
+}
+
 gboolean
 banshee_is_debugging ()
 {
