@@ -28,7 +28,7 @@
 //
 
 using System;
-using System.Data;
+using System.Linq;
 using System.Text;
 using System.Collections.Generic;
 
@@ -275,7 +275,7 @@ namespace Banshee.Query
 
         public static QueryField MimeTypeField = new QueryField (
             "mimetype", "MimeType",
-            Catalog.GetString ("Mime Type"), "CoreTracks.MimeType {0} OR CoreTracks.Uri {0}", typeof(ExactStringQueryValue),
+            Catalog.GetString ("Mime Type"), "CoreTracks.MimeType", typeof(ExactStringQueryValue),
             // Translators: These are unique search fields. You can use CSV for synonyms. Please, no spaces. Blank ok.
             Catalog.GetString ("type"), Catalog.GetString ("mimetype"), Catalog.GetString ("format"), Catalog.GetString ("ext"),
             "type", "mimetype", "format", "ext", "mime"
@@ -515,7 +515,7 @@ namespace Banshee.Query
 
         private static QueryOrder CreateQueryOrder (string name, bool asc, string label, QueryField field)
         {
-            return new QueryOrder (CreateOrderName (name, asc), label, GetSort (name, asc), field);
+            return new QueryOrder (CreateOrderName (name, asc), label, GetSort (name, asc), field, asc);
         }
 
         public static QueryLimit FindLimit (string name)
@@ -527,6 +527,11 @@ namespace Banshee.Query
             return null;
         }
 
+        public static QueryOrder FindOrder (QueryField field, bool asc)
+        {
+            return Orders.FirstOrDefault (o => o != null && o.Field == field && o.Ascending == asc);
+        }
+
         public static QueryOrder FindOrder (string name, bool asc)
         {
             return FindOrder (CreateOrderName (name, asc));
